PyXMake Developer Guide: PyXMake.VTL.stm_make.pylint Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
PyXMake.VTL.stm_make.pylint Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pylint:

## Public Member Functions
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)

## Public Attributes
| command
| out
| output_file_path
| verbose

## Static Public Attributes
string | description = "Runs the pylint command."
list | user_options

## Detailed Description

    Runs the pylint command.

Definition at line 896 of file stm_make.py.

## Member Data Documentation

## ◆ user_options

list PyXMake.VTL.stm_make.pylint.user_options
| static

Initial value:
= [
("command=", None, "Path and name of the command line tool."),
("out=", None, "Specifies the output type (html, parseable). Default: html")]

Definition at line 903 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py